@@ -766,8 +766,10 @@ void WriteStringToStream(char *str,
 	out->data = (char *)MemAlloc(out->datasize);
 	out->datapos = 0;
     }
+    /* Resize as necessary */
     else if (out->datapos + size >= out->datasize) {
-	out->datasize += out->datasize >> 1;
+	while (out->datapos + size >= out->datasize)
+	    out->datasize += out->datasize >> 1;
 	out->data = (char *)MemRealloc(out->data, out->datasize);
     }
     memcpy(out->data, str, size);
