@@ -1,7 +1,7 @@
 /* 
   mxTidy -- Interface to HTML Tidy (HTML/XML beautifier)
 
-  Copyright (c) 2001-2002, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2001-2007, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -20,6 +20,9 @@
 /* We want all our symbols to be exported */
 #define MX_BUILDING_MXTIDY
 
+/* Mark the module as Py_ssize_t clean. */
+#define PY_SSIZE_T_CLEAN 1
+
 #include "mx.h"
 #include "mxTidy.h"
 
@@ -27,7 +30,7 @@
 #include "htmltidy.h"
 
 /* Version number: Major.Minor.Patchlevel */
-#define VERSION "0.3.0"
+#define MXTIDY_VERSION "0.4.0"
 
 /* --- module doc-string -------------------------------------------------- */
 
@@ -35,9 +38,9 @@ static char *Module_docstring =
 
  MXTIDY_MODULE" -- Interface to Tidy (HTML beautifier).\n\n"
 
- "Version "VERSION"\n\n"
+ "Version "MXTIDY_VERSION"\n\n"
 
- "Copyright (c) 2001-2002, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2001-2007, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -373,12 +376,6 @@ PyObject *mxTidy_RunTidy(PyObject *inputstream,
 
     }
 
-    /* XXX Music:
-
-       ETAGE 3 - hotel costes; mixed by Stephane Pompougnac
-
-     */
-    
     /* ensure config is self-consistent */
     AdjustConfig(config);
 
@@ -715,7 +712,7 @@ MX_EXPORT(void)
     moddict = PyModule_GetDict(module);
     PyDict_SetItemString(moddict, 
 			 "__version__",
-			 PyString_FromString(VERSION));
+			 PyString_FromString(MXTIDY_VERSION));
 
     /* Errors */
     if (!(mxTidy_Error = insexc(moddict, "Error", PyExc_StandardError)))
